@@ -54,6 +54,9 @@ impl Opt {
         if args.custom_ascii_color.is_some() {
             self.custom_ascii_color = args.custom_ascii_color;
         }
+        if args.version {
+            self.version = true;
+        }
         if args.doctor {
             self.doctor = true;
         }
@@ -96,8 +99,8 @@ impl Opt {
         if args.separator_color.is_some() {
             self.separator_color = args.separator_color;
         }
-        if args.short_shell {
-            self.short_shell = true;
+        if args.long_shell {
+            self.long_shell = true;
         }
         if args.short_uptime {
             self.short_uptime = true;
@@ -124,38 +127,6 @@ impl Opt {
             conflicts.push("hide and show_only");
         }
 
-        if self.separator_color.is_some() && self.no_separator {
-            conflicts.push("separator_color and no_separator");
-        }
-
-        if self.color.is_some() && self.no_color {
-            conflicts.push("color and no_color");
-        }
-
-        if self.separator_color.is_some() && self.no_color {
-            conflicts.push("separator_color and no_color");
-        }
-
-        if self.custom_ascii.is_some() && self.no_ascii {
-            conflicts.push("custom_ascii and no_ascii");
-        }
-
-        if self.custom_ascii_color.is_some() && self.no_ascii {
-            conflicts.push("custom_ascii_color and no_ascii");
-        }
-
-        if self.small_ascii && self.no_ascii {
-            conflicts.push("small_ascii and no_ascii");
-        }
-
-        if self.box_title.is_some() && self.no_box {
-            conflicts.push("box_title and no_box");
-        }
-
-        if self.box_title.is_some() && self.no_title {
-            conflicts.push("box_title and no_title");
-        }
-
         conflicts
     }
 }
